Board manager
=============

BoardState
----------

.. autoclass:: sokoenginepy.game.BoardState
    :members:
    :undoc-members:


BoardManager
------------

.. autoexception:: sokoenginepy.game.BoxGoalSwitchError

.. autoexception:: sokoenginepy.game.CellAlreadyOccupiedError

.. autoclass:: sokoenginepy.game.BoardManager
    :members:
    :undoc-members:
    :inherited-members:


HashedBoardManager
------------------

.. autoclass:: sokoenginepy.game.HashedBoardManager
    :members:
    :undoc-members:
    :show-inheritance:


SokobanPlus
-----------

.. autoexception:: sokoenginepy.game.SokobanPlusDataError

.. autoclass:: sokoenginepy.game.SokobanPlus
    :members:
    :undoc-members:
    :inherited-members:
